#
# spec file for package gnome-connections
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-connections
Version:        42.1.2
Release:        bp156.2.6
Summary:        A remote desktop client for GNOME
License:        GPL-3.0-or-later
URL:            https://wiki.gnome.org/Apps/Connections
Source:         https://download.gnome.org/sources/gnome-connections/42/%{name}-%{version}.tar.xz

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(freerdp2) >= 2.0.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.50
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gtk-vnc-2.0) > 0.4.4
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.7.8
BuildRequires:  pkgconfig(winpr2) >= 2.0.0

%description
A remote desktop client for the GNOME desktop environment.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}
# gtk-frdp is a subproject, do not offer it for consumption outside
rm -rf %{buildroot}%{_includedir}/%{name}/gtk-frdp/
rm %{buildroot}%{_libdir}/gnome-connections/pkgconfig/gtk-frdp-0.1.pc
rm %{buildroot}%{_datadir}/gnome-connections/gir-1.0/GtkFrdp-0.1.gir
rm %{buildroot}%{_datadir}/gnome-connections/vapi/gtk-frdp-0.1.deps
rm %{buildroot}%{_datadir}/gnome-connections/vapi/gtk-frdp-0.1.vapi

%check
%meson_test

%files
%license COPYING
%{_bindir}/gnome-connections
%dir %{_libdir}/gnome-connections
%dir %{_libdir}/gnome-connections/girepository-1.0
%{_libdir}/gnome-connections/girepository-1.0/GtkFrdp-0.1.typelib
%{_libdir}/gnome-connections/libgtk-frdp-0.1.so
%{_datadir}/metainfo/org.gnome.Connections.appdata.xml
%{_datadir}/applications/org.gnome.Connections.desktop
%{_datadir}/dbus-1/services/org.gnome.Connections.service
%{_datadir}/glib-2.0/schemas/org.gnome.Connections.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Connections.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Connections-symbolic.svg
%{_datadir}/mime/packages/org.gnome.Connections.xml

%files lang -f %{name}.lang

%changelog
* Wed Apr 13 2022 Emily Gonyer <emilyyrose@gmail.com>
- Changes from 42.1.1:
  + Fix handling of non-char keyboard input.
* Fri Apr  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.1.1:
  + Fix crash with multiple simultaneous connections.
  + Allow for resizing and maximizing a display view.
  + Reset credentials when authentication fails.
  + Fix connection deletion on notification timeout.
- Changes from version 42.1:
  + Fixed double-free crash while connecting to RDP servers.
  + Fixed RDP scaling and resizing issues.
  + Updated translations.
* Mon Mar 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Add screenshots to appdata.
  + Updated translations.
* Wed Mar  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Finalize deleted connections
  + Save credentials in the keyring
  + Expose setting to enable/disable audio for VNC connections
  + Fix clibpard issues with VNC
  + Fix issue with the search grabing input from display
  + Added libhandy color scheme API
  + Improve thumbnail drawing logic
  + Updated translations.
- Add pkgconfig(libsecret-1) BuildRequires: New dependency.
- Add optional appstream-glib and desktop-file-utils BuildRequires:
  validate appstream and desktop file during build (meson_test).
* Tue Dec  7 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add check section and meson_test macro, run tests during build.
* Fri Dec  3 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + rdp-connection: Call show () when opening an already
    established connection
  + preferences: Remove activatable_widget property for the host
    address
  + build: Don't use internet for appstream validation test
  + vnc-connection: Only paste clipboard content that is text
  + Updated translations.
* Wed Oct 27 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Prevent search from stealing display key-press events.
  + Improve the parsing of incomplete addresses.
  + Draw RDP thumbnails on the app side.
  + Do not tap to clipboard until VNC connection is connected.
  + Fix missing app title in the Shell.
  + Add parameters to the Exec key in the desktop file.
  + Updated translations.
* Fri Sep 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + No changes.
* Thu Sep  2 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.rc:
  + Fix interactive authentication of RDP connections
  + Improve thumbnailer efficiency
- Changes from version 41.beta:
  + New onboarding dialog with instructions to use the app
  + Allow window to shrink
  + Connect to address after adding it
  + Validate server addresses
  + Display connection errors as notifications
  + Add command line option to launch a connection in fullscreen
  + Indicate that a connection is open by showing its thumbnail
  + Various internal refactorings
  + Updated translations.
- Changes from version 41.alpha:
  + Add shared clipboard support for VNC connections
  + Add a preferences dialog (based in Hdy.PreferencesWindow)
  + Introduce Onboarding dialog
  + Add new application icon
  + Add new connection creation assistant
  + Handle authentication failures
  + Add fullscreen support
  + Add VNC display scale modes setting
  + Default display scaling to "fit-window"
  + Add "vnc, rdp, remote" keywords to desktop file
  + Enable type-to-search in the main view
  + Only show search button when collection isn't empty
  + Dismiss notifications on exit
  + Add a few keyboard shortcuts
  + Update app metadata
  + Updated translations.
- Add pkgconfig(libhandy-1) BuildRequires: New dependency.
* Tue Apr 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 40.0.1.
